@@ -27,6 +27,14 @@ test_that("Row merging done correctly", {
   expect_equal(length(m3), 280)
 })
 
+test_that("Row merging with a list done correctly", {
+  m3 <- RowMergeMatricesList(mat_list = list(m1, m2), mat_rownames = list(m1.names, m2.names), all_rownames = all.names)
+  expect_equal(m3[1, 14], -0.17)
+  expect_equal(m3[3, 2], -1.4)
+  expect_equal(m3[14, 18], -0.43)
+  expect_equal(length(m3), 280)
+})
+
 # Tests for log normalization
 # --------------------------------------------------------------------------------
 context("Log Normalization")
@@ -40,36 +48,22 @@ test_that("Log Normalization returns expected values", {
   expect_equal(mat.norm[4, 4], mat.norm.r[4, 4])
 })
 
-# Tests for matrix multiply
-# --------------------------------------------------------------------------------
-context("Matrix Multiply")
-
-mat <- as.matrix(mat)
-
-test_that("Fast implementation of matrix multiply returns as expected", {
-  expect_equal(mat %*% mat, FastMatMult(mat, mat))
-  mat[1, 1] <- NA
-  expect_equal(mat %*% mat, FastMatMult(mat, mat))
-  mat[1, 1] <- NaN
-  expect_equal(mat %*% mat, FastMatMult(mat, mat))
-})
-
 # Tests for scaling data
 # --------------------------------------------------------------------------------
 context("Fast Scale Data Functions")
 
-mat <- matrix(seq(0.001, 0.1, 0.001), nrow = 10, ncol = 10)
+mat <- matrix(rnorm(n = 10*15), nrow = 10, ncol = 15)
 
 # should be the equivalent of t(scale(t(mat)))
 test_that("Fast implementation of row scaling returns expected values", {
-  expect_equal(t(scale(t(mat))[1:10, 1:10]), FastRowScale(mat, display_progress = FALSE))
-  expect_equal(t(scale(t(mat), center = FALSE))[1:10, 1:10],
-               FastRowScale(mat, center = FALSE, display_progress = FALSE))
-  expect_equal(t(scale(t(mat), scale = FALSE))[1:10, 1:10],
-               FastRowScale(mat, scale = FALSE, display_progress = FALSE))
-  expect_equal(t(scale(t(mat), scale = FALSE, center = F))[1:10, 1:10],
-               FastRowScale(mat, scale = FALSE, center = F, display_progress = FALSE))
-  mat.clipped <- FastRowScale(mat, scale_max = 0.2, display_progress = F)
+  expect_equal(t(scale(t(mat)))[1:10, 1:15], FastRowScale(mat))
+  expect_equal(t(scale(t(mat), center = FALSE))[1:10, 1:15],
+               FastRowScale(mat, center = FALSE))
+  expect_equal(t(scale(t(mat), scale = FALSE))[1:10, 1:15],
+               FastRowScale(mat, scale = FALSE))
+  expect_equal(t(scale(t(mat), scale = FALSE, center = F))[1:10, 1:15],
+               FastRowScale(mat, scale = FALSE, center = F))
+  mat.clipped <- FastRowScale(mat, scale_max = 0.2)
   expect_true(max(mat.clipped, na.rm = T) >= 0.2)
 })
 
